@@ -1,2 +1,7 @@
 utils::globalVariables(c("sg_sum", "id_sg", "sg_session_n", "sg_magnitude", "session",  "sg_magnitude", "session", "sg_crit123", "sg_freq_byperson", "sg_magnitude", "sg_reversal_value", "sg_change_proportion", "time_str", "time_num", "index", "value", "sg_crit123", ".", "sg_freq_byperson", "sg_reversal", "sg_magnitude", "time_str", "time_num", "index", "name", "value", "x_n_pre2", "x_n_pre1", "x_n", "x_n_post1", "x_n_post2", "x_n_post3", "variable", "value", "pattern", "sg_pattern_1", "sg_pattern_2", "sg_pattern_3", "sg_pattern_4", "sg_select", "nvalid",
-                         "start_fun", "pre3_fun" , "pre2_fun", "pre1_fun", "post1_fun", "post2_fun", "post3_fun", "end_fun"))
+                         "start_fun", "pre3_fun" , "pre2_fun", "pre1_fun", "post1_fun", "post2_fun", "post3_fun", "end_fun", "available_between_sess_sg", "id", "not_available_between_sess_sg", "pct_miss", "total_not_available_sg"))
+
+
+
+
+
